typedef union {long itype; tree ttype; char *strtype; enum tree_code code; flagged_type_tree ftype; } YYSTYPE;
#define	IDENTIFIER	258
#define	TYPENAME	259
#define	SELFNAME	260
#define	PFUNCNAME	261
#define	SCSPEC	262
#define	TYPESPEC	263
#define	CV_QUALIFIER	264
#define	CONSTANT	265
#define	STRING	266
#define	ELLIPSIS	267
#define	SIZEOF	268
#define	ENUM	269
#define	IF	270
#define	ELSE	271
#define	WHILE	272
#define	DO	273
#define	FOR	274
#define	SWITCH	275
#define	CASE	276
#define	DEFAULT	277
#define	BREAK	278
#define	CONTINUE	279
#define	RETURN_KEYWORD	280
#define	GOTO	281
#define	ASM_KEYWORD	282
#define	TYPEOF	283
#define	ALIGNOF	284
#define	SIGOF	285
#define	ATTRIBUTE	286
#define	EXTENSION	287
#define	LABEL	288
#define	REALPART	289
#define	IMAGPART	290
#define	AGGR	291
#define	VISSPEC	292
#define	DELETE	293
#define	NEW	294
#define	THIS	295
#define	OPERATOR	296
#define	CXX_TRUE	297
#define	CXX_FALSE	298
#define	NAMESPACE	299
#define	TYPENAME_KEYWORD	300
#define	USING	301
#define	LEFT_RIGHT	302
#define	TEMPLATE	303
#define	TYPEID	304
#define	DYNAMIC_CAST	305
#define	STATIC_CAST	306
#define	REINTERPRET_CAST	307
#define	CONST_CAST	308
#define	SCOPE	309
#define	EMPTY	310
#define	PTYPENAME	311
#define	NSNAME	312
#define	THROW	313
#define	ASSIGN	314
#define	OROR	315
#define	ANDAND	316
#define	MIN_MAX	317
#define	EQCOMPARE	318
#define	ARITHCOMPARE	319
#define	LSHIFT	320
#define	RSHIFT	321
#define	POINTSAT_STAR	322
#define	DOT_STAR	323
#define	UNARY	324
#define	PLUSPLUS	325
#define	MINUSMINUS	326
#define	HYPERUNARY	327
#define	PAREN_STAR_PAREN	328
#define	POINTSAT	329
#define	TRY	330
#define	CATCH	331
#define	PRE_PARSED_FUNCTION_DECL	332
#define	EXTERN_LANG_STRING	333
#define	ALL	334
#define	PRE_PARSED_CLASS_DECL	335
#define	DEFARG	336
#define	DEFARG_MARKER	337
#define	TYPENAME_DEFN	338
#define	IDENTIFIER_DEFN	339
#define	PTYPENAME_DEFN	340
#define	END_OF_LINE	341
#define	END_OF_SAVED_INPUT	342


extern YYSTYPE yylval;
#define YYEMPTY		-2
